@@ -426,6 +426,42 @@ int stepper_move_flags_to_betza(move_flag_t flags, char *buffer, size_t size) co
    return n;
 }
 
+int rider_move_flags_to_betza(move_flag_t flags, char *buffer, size_t size) const
+{
+   int n = 0;
+
+   static struct {
+      int dx, dy;
+      const char *txt;
+      int symmetry;
+   } leaper_description[] = {
+      { 1, 0, "W", 4 },
+      { 1, 1, "F", 4 },
+      { 2, 0, "D", 4 },
+      { 2, 1, "N", 8 },
+      { 2, 2, "A", 4 },
+      { 3, 0, "H", 4 },
+      { 3, 1, "C", 8 },
+      { 3, 2, "Z", 8 },
+      { 3, 3, "G", 4 },
+      { 0, 0, NULL, 0 }
+   };
+
+   int index = get_rider_index(flags);
+   for (int k=0; k<4; k++)
+   for (int nn = 0; leaper_description[nn].txt; nn++) {
+      int dx = leaper_description[nn].dx;
+      int dy = leaper_description[nn].dy;
+      if ((dx == movegen.rider_step[index][k].dx && dy == movegen.rider_step[index][k].dy) ||
+          (dy == movegen.rider_step[index][k].dx && dx == movegen.rider_step[index][k].dy)) {
+         n += snprintf(buffer+n, size-n, "%s0", leaper_description[nn].txt);
+         break;
+      }
+   }
+
+   return n;
+}
+
 const char *move_flags_to_betza(move_flag_t flags, char *buffer = NULL, size_t size = 256) const
 {
    static char static_buffer[256] = { 0 };
@@ -451,6 +487,11 @@ const char *move_flags_to_betza(move_flag_t flags, char *buffer = NULL, size_t s
    flags &= ~MF_LEAPER_FLAGS;
    if (flags == 0) goto done;
 
+   /* Describe rider moves */
+   n += rider_move_flags_to_betza(flags, buffer + n, size - n);
+   flags &= ~MF_RIDER;
+   if (flags == 0) goto done;
+
    /* Describe stepper moves */
    n += stepper_move_flags_to_betza(flags, buffer + n, size - n);
    flags &= ~MF_STEPPER;
