@@ -58,11 +58,15 @@
 #define RF_USE_SHAKMATE       0x00010000  /* The checking sequence prior to mate needs particular pieces */
 #define RF_USE_BARERULE       0x00020000  /* Shatranj-style baring rule */
 #define RF_USE_CHASERULE      0x00040000  /* Xiangqi-style chase rule is in effect */
+#define RF_QUIET_PROMOTION    0x00080000  /* Promotion moves must be quiet moves (Sittuyin style) */
 
 #define RF_CAPTURE_ANY_FLAG   0x00100000  /* There is a "capture the flag" victory condition. */
 #define RF_CAPTURE_ALL_FLAG   0x00200000  /* There is a "capture the flag" victory condition. */
 #define RF_CAPTURE_THE_FLAG   (RF_CAPTURE_ANY_FLAG | RF_CAPTURE_ALL_FLAG)  /* There is a "capture the flag" victory condition. */
 
+#define RF_NO_MOVE_PAST_CHECK 0x00400000  /* Sliding royals may not slide through check */
+#define RF_PROMOTE_BY_MOVE    0x00800000  /* Promote by moving as target piece */
+
 /* Board state */
 #define BF_CHECK              0x0001      /* Whether the side to move is in-check or not */
 #define BF_WSHAK              0x0002      /* Whether a "shak" was given or not */
@@ -179,6 +183,8 @@ struct board_t {
 
    void put_piece(int type, side_t side, int square)
    {
+      assert(!bbc[side].test(square));
+      assert(!bbp[type].test(square));
       bbc[side].set(square);
       bbp[type].set(square);
       piece[square] = type;
@@ -190,6 +196,9 @@ struct board_t {
 
    void clear_piece(int type, side_t side, int square)
    {
+      assert(bbc[side].test(square));
+      assert(bbp[type].test(square));
+      assert(piece[square] == type);
       bbc[side].reset(square);
       bbp[type].reset(square);
       royal.reset(square);
@@ -231,6 +240,61 @@ struct board_t {
       return -1;
    }
 
+   void print_move(move_t move) const
+   {
+      side_t swap_side[3];
+      int    swap_piece[3];
+      int    swap_to[3];
+      int    n;
+
+      /* Second: resolve all pickups */
+      n = get_move_pickups(move);
+      printf("\n%d pickups\n", n);
+      for (int c=0; c<n; c++) {
+         uint16_t p  = get_move_pickup(move, c);
+         int square  = decode_pickup_square(p);
+         int piece   = get_piece(square);
+         side_t side = get_side(square);
+
+         printf("%d %s %s %d\n", c, square_names[square], piece_types->piece_abbreviation[piece][side], side);
+      }
+
+      /* Third: resolve all swaps */
+      n = get_move_swaps(move);
+      printf("%d swaps\n", n);
+      for (int c=0; c<n; c++) {
+         uint16_t p    = get_move_swap(move, c);
+         int from      = decode_swap_from(p);
+         swap_to[c]    = decode_swap_to(p);
+         swap_piece[c] = get_piece(from);
+         swap_side[c]  = get_side(from);
+
+         printf("%d %s %s %s\n", c, square_names[from], square_names[swap_to[c]], piece_types->piece_abbreviation[swap_piece[c]][swap_side[c]]);
+      }
+
+      /* Fourth: resolve all drops */
+      n = get_move_drops(move);
+      printf("%d drops\n", n);
+      for (int c=0; c<n; c++) {
+         uint16_t p  = get_move_drop(move, c);
+         int square  = decode_drop_square(p);
+         int piece   = decode_drop_piece(p);
+         side_t side = decode_drop_side(p);
+
+         printf("%d %s %s %d\n", c, square_names[square], piece_types->piece_abbreviation[piece][side], side);
+      }
+
+      /* Fifth: update holdings */
+      if ((rule_flags & RF_USE_HOLDINGS) && get_move_holdings(move)) {
+         uint16_t p  = get_move_holding(move);
+         int count   = decode_holding_count(p);
+         int piece   = decode_holding_piece(p);
+         side_t side = decode_holding_side(p);
+         printf("Holdings %s %d\n", piece_types->piece_abbreviation[piece][side], count);
+      }
+   }
+
+
    void makemove(move_t move, unmake_info_t<kind> *ui)
    {
       side_t swap_side[3];
