@@ -54,7 +54,7 @@ bitboard_t<kind> get_chased_pieces(int backtrack)
       int from = get_move_from(move);
       int cap  = get_move_capture_square(move);
 
-      if (get_move_piece(move) == board.get_piece(cap)) {
+      if (board.get_piece(from) == board.get_piece(cap)) {
          move_flag_t flags = board.piece_types->piece_capture_flags[n];
 
          if (is_leaper(flags) && is_masked_leaper(flags)) {
@@ -164,6 +164,9 @@ inline chase_state_t test_chase()
    //printf("Black chasing (%d)\n", chasing[BLACK]);
    //chased_pieces[WHITE].print();
 
+   //if (!chasing[WHITE] && !chasing[BLACK])
+   //   return NO_CHASE;
+
    if (chasing[WHITE] == chasing[BLACK])
       return DRAW_CHASE;
 
