@@ -118,7 +118,7 @@ struct eval_pair_t {
    }
 
    inline const eval_pair_t operator *(const float &rhs) const {
-      return eval_pair_t(this->mg * rhs, this->eg * rhs);
+      return eval_pair_t(int(this->mg * rhs), int(this->eg * rhs));
    }
 
    inline eval_t interpolate(int x, int scale) const {
