@@ -128,8 +128,10 @@ eval_t game_template_t<kind>::static_evaluation(side_t side_to_move, int /* alph
    eval_pair_t mob = 0;     // Mobility
    eval_pair_t pss = 0;     // Pawn structure score
    eval_pair_t kss = 0;     // King safety score
+   eval_pair_t tp = 0;      // Tempo bonus  
    eval_t ev = 0;
    eval_t hash_ev = 0;
+   eval_t tempo = 0;
    int phase = 0;
    bool symmetric = true;
 
@@ -266,6 +268,7 @@ eval_t game_template_t<kind>::static_evaluation(side_t side_to_move, int /* alph
             attacks[side][piece] |= atk;
             all_attacks[side]    |= atk;
             attack[square] = atk;
+            moves[square] &= ~occ;
 
             if (pt.defensive_pieces & (1<<piece))
                defatk |= attacks[side][piece];
@@ -433,7 +436,7 @@ eval_t game_template_t<kind>::static_evaluation(side_t side_to_move, int /* alph
             int df = abs(unpack_file(king[side]) - unpack_file(king[oside]));
             int dr = abs(unpack_rank(king[side]) - unpack_rank(king[oside]));
             psq = 4*(std::max(dr*dr, df*df) - 4);
-            bitboard_t<kind> bb = board.bbp[oside];
+            bitboard_t<kind> bb = board.bbc[oside];
             while (!bb.is_empty()) {
                int square = bb.bitscan();
                bb.reset(square);
@@ -696,6 +699,25 @@ eval_t game_template_t<kind>::static_evaluation(side_t side_to_move, int /* alph
       assert(si == square_count);
    }
 
+   /* Disable phase-scaling in variants where captured pieces are returned:
+    * there material does not represent game phase.
+    */
+   if (board.rule_flags & RF_USE_CAPTURE) phase = pt.phase_scale;
+
+   if ( board.rule_flags & (RF_USE_CAPTURE | RF_ALLOW_PICKUP) ) {
+      int t = 0;
+      for (int piece = 0; piece<pt.num_piece_types; piece++) {
+         if (board.holdings[piece][side_to_move]) {
+            t += TEMPO_DROP_WEIGHT*std::max(1, pt.king_safety_weight[piece]);
+         }
+      }
+      tp.mg = t;
+      tp.eg = 0;
+
+      /* Calculate tempo bonus */
+      tempo = std::min((eval_t)TEMPO_DROP_MAX, tp.interpolate(phase, pt.phase_scale));
+      if (tempo) symmetric = false;
+   }
 
    if (print) {
       printf("Component:       MG:    EG:\n");
@@ -704,13 +726,9 @@ eval_t game_template_t<kind>::static_evaluation(side_t side_to_move, int /* alph
       printf("Mobility:        % 4d   % 4d\n", mob.mg, mob.eg);
       printf("Pawn structure:  % 4d   % 4d\n", pss.mg, pss.eg);
       printf("King safety:     % 4d   % 4d\n", kss.mg, kss.eg);
+      printf("Tempo:           % 4d   % 4d\n",  tp.mg,  tp.eg);
    }
 
-   /* Disable phase-scaling in variants where captured pieces are returned:
-    * there material does not represent game phase.
-    */
-   if (board.rule_flags & RF_USE_CAPTURE) phase = pt.phase_scale;
-
    /* Interpolate evaluation score. */
    ev = (mat + psq + mob + pss + kss).interpolate(phase, pt.phase_scale);
 
@@ -762,5 +780,5 @@ exit:
       ev += r;
    }
 
-   return (side_to_move == WHITE) ? ev : -ev;
+   return ((side_to_move == WHITE) ? ev : -ev) + tempo;
 }
