@@ -7,13 +7,17 @@ void inline store_counter_move(int /* depth */, move_t prev_move, move_t move)
       return;
 
    int side = board.side_to_move;
-   counter[get_move_from(prev_move)][get_move_to(prev_move)][side] = move;
+   int to   = get_move_to(prev_move);
+   int from = is_drop_move(prev_move) ? to : get_move_from(prev_move);
+   counter[from][to][side] = move;
 }
 
 bool inline is_counter(int /* depth */, move_t prev_move, move_t move) const
 {
    int side = board.side_to_move;
-   return counter[get_move_from(prev_move)][get_move_to(prev_move)][side] == move;
+   int to   = get_move_to(prev_move);
+   int from = is_drop_move(prev_move) ? to : get_move_from(prev_move);
+   return counter[from][to][side] == move;
 }
 
 bool is_killer(int depth, move_t move) const
