@@ -70,6 +70,11 @@ int msearch(int alpha, int beta, int mply, int depth, int ply = 0)
    if (ply == 0 && !(mply & 1)) mply--;
    if (mply < 0 || depth >= MAX_SEARCH_DEPTH) return 0;
 
+   /* If the position is repeated, it cannot be part of a line of optimal
+    * play.
+    */
+   if (position_repeated()) return 0;
+
    /* Test for transposition table cut-offs */
    int hash_depth, hash_score;
    unsigned int hash_flag;
