@@ -4,7 +4,6 @@ move_t move_string_to_move(const char *move_str, const movelist_t *external_move
    movelist_t movelist;
    int src = 0, dest = 0, ppiece = 0;
    char *s;
-   int n;
 
    /* First, generate the list of moves for this position */
    if (external_movelist) {
@@ -53,6 +52,13 @@ move_t move_string_to_move(const char *move_str, const movelist_t *external_move
       /* Other alternates? *TODO* */
    }
 
+   /* No match, but perhaps the input includes a "+" for a checking move? */
+   int l = strlen(ms);
+   if (ms[l-1] == '+') {
+      ms[l-1] = '\0';
+      return move_string_to_move(ms, &movelist);
+   }
+
    return 0;
 }
 
