@@ -249,6 +249,7 @@ inline bool zugzwang_threat()
 bool is_pawn_push(move_t move, side_t side)
 {
    if (pt.pawn_pieces & (1 << board.get_piece(get_move_from(move)))) {
+      if (is_drop_move(move)) return false;
       if (bitboard_t<kind>::board_homeland[next_side[side]].test(get_move_from(move)))
          return true;
    }
@@ -302,7 +303,7 @@ void score_moves(int depth, move_t hash_move, move_t prev_move, move_t threat_mo
          else
             movelist[depth].score[n] += s;
 
-         if (threat_move && get_move_to(move) == get_move_from(threat_move) && s < 0)
+         if (threat_move && !is_drop_move(threat_move) && get_move_to(move) == get_move_from(threat_move) && s < 0)
             movelist[depth].score[n] += 1000;
       } else if (is_pickup_move(move)) {
          if (threat_move && get_move_to(threat_move) == get_move_from(move)) {
@@ -660,6 +661,15 @@ int search(int alpha, int beta, int draft, int depth)
                                            : check_score + depth;
    }
 
+   /* Test if the last move was an illegal promotion */
+   if ((board.rule_flags & RF_QUIET_PROMOTION) && moves_played > 0 && is_promotion_move(move_list[moves_played-1]) ) {
+      if (board.check()) return ILLEGAL;
+      int square = get_move_to(move_list[moves_played-1]);
+      int p = board.get_piece(square);
+      bitboard_t<kind> atk = movegen.generate_move_bitboard_for_flags(pt.piece_capture_flags[p], square, board.get_occupied(), next_side[board.side_to_move]);
+      if (!(atk & board.bbc[board.side_to_move]).is_empty()) return ILLEGAL;
+   }
+
    //if ( (depth == 0 || depth == 1 || draft > 8 || is_mate_score(beta)) && (board.rule_flags & RF_USE_DROPS)) {
    bool mate_search = (depth == 1) ||
                       (depth == 0 && best_move[0] != 0) ||
@@ -964,14 +974,18 @@ void print_principle_variation(int d = 0)
    int root_move_number = start_move_count;
 
    if (board.side_to_move) {
-      root_move_number += 1;
       iter(" %d. ...", (int)(root_move_number+moves_played)/2+1);
+      root_move_number += 1;
    }
    for (c=0; c<length_of_variation[d]; c++) {
-      if (((root_move_number+c) & 1) == 0)
-         iter(" %d.", (int)(root_move_number+moves_played)/2+1);
       movelist_t movelist;
       generate_legal_moves(&movelist);
+      if (!movelist.contains(principle_variation[c][0])) {
+         length_of_variation[d] = c;
+         break;
+      }
+      if (board.side_to_move == WHITE)
+         iter(" %d.", (int)(root_move_number+moves_played)/2+1);
       iter(" %-6s", move_to_short_string(principle_variation[c][d], &movelist, NULL, castle_san_ok));
       playmove(principle_variation[c][d]);
    }
@@ -979,7 +993,7 @@ void print_principle_variation(int d = 0)
       takeback();
 }
 
-void print_principle_variation_xb(movelist_t *movelist = NULL)
+void print_principle_variation_xb(void)
 {
    int c;
    int root_move_number = start_move_count;
@@ -989,9 +1003,15 @@ void print_principle_variation_xb(movelist_t *movelist = NULL)
       root_move_number += 1;
    }
    for (c=0; c<length_of_variation[0]; c++) {
-      if (((root_move_number+c) & 1) == 0)
+      movelist_t movelist;
+      generate_legal_moves(&movelist);
+      if (!movelist.contains(principle_variation[c][0])) {
+         length_of_variation[0] = c;
+         break;
+      }
+      if (board.side_to_move == WHITE)
          xb(" %d.", (int)(root_move_number+moves_played)/2+1);
-      xb(" %s", move_to_short_string(principle_variation[c][0], movelist, NULL, castle_san_ok));
+      xb(" %s", move_to_short_string(principle_variation[c][0], &movelist, NULL, castle_san_ok));
       playmove(principle_variation[c][0]);
    }
    for (c=0; c<length_of_variation[0]; c++)
@@ -1013,13 +1033,9 @@ void store_principle_variation(int score, int depth)
    if ((score - depth) < -LEGALWIN) depth = LEGALWIN + score;
    if ((score + depth) >  LEGALWIN) depth = LEGALWIN - score;
    for (int c=0; c<length_of_variation[0]; c++) {
-      store_table_entry(transposition_table, board.hash, depth-c, score_to_hashtable(score, depth-c), HASH_TYPE_EXACT, principle_variation[c][0]);
+      store_table_entry(transposition_table, board.hash, depth-c, score_to_hashtable(score, c), HASH_TYPE_EXACT, principle_variation[c][0]);
       playmove(principle_variation[c][0]);
 
-      if (score_to_hashtable(score, depth-c) == -LEGALWIN) {
-         length_of_variation[0] = c+1;
-         break;
-      }
       score = -score;
    }
    for (int c=0; c<length_of_variation[0]; c++)
@@ -1031,7 +1047,7 @@ play_state_t get_game_end_state(movelist_t *movelist = NULL)
    movelist_t static_movelist;
    if (movelist == NULL) movelist = &static_movelist;
 
-   board.check(movegen.player_in_check(&board, board.side_to_move));
+   test_move_game_check();
    if ((board.rule_flags & RF_USE_SHAKMATE) && board.check()) test_shak();
 
    /* Count a number of obvious things: repetition draw, 50 move rule */
@@ -1183,7 +1199,7 @@ void score_static_moves(movelist_t *movelist)
       }
 
       int piece = get_move_piece(move);
-      int pst = centre_table[get_move_to(move)] - centre_table[get_move_from(move)];
+      int pst = centre_table[get_move_to(move)] - (is_drop_move(move) ? 0 : centre_table[get_move_from(move)]);
       if (pt.royal_pieces & (1<<piece)) {
          movelist->score[n] += (-pst*4*phase + pst*(pt.phase_scale - phase)) / pt.phase_scale;
       } else {
@@ -1194,7 +1210,7 @@ void score_static_moves(movelist_t *movelist)
       if (moves_played >= 2) {
          move_t prev_move = move_list[moves_played-2];
 
-         if (get_move_from(move) == get_move_to(prev_move)) {
+         if (!is_drop_move(move) && !is_drop_move(prev_move) && get_move_from(move) == get_move_to(prev_move)) {
             movelist->score[n] -= 10;
             if (get_move_to(move) == get_move_from(prev_move))
                movelist->score[n] -= 100;
@@ -1206,7 +1222,7 @@ void score_static_moves(movelist_t *movelist)
          pawn_structure_t<kind> ps;
          calculate_pawn_structure(&ps);
 
-         if (ps.passed.test(get_move_from(move)))
+         if (!is_drop_move(move) && ps.passed.test(get_move_from(move)))
             movelist->score[n] += 50;
       }
 
@@ -1217,7 +1233,7 @@ void score_static_moves(movelist_t *movelist)
        *    pieces, and the like.
        */
 
-      if (threat_see && !threat.test(get_move_from(move)))
+      if (threat_see && !is_drop_move(move) && !threat.test(get_move_from(move)))
          movelist->score[n] -= threat_see;
 
 
@@ -1321,7 +1337,7 @@ play_state_t think(int max_depth)
       length_of_variation[0] = 1;
       principle_variation[0][0] = best_move[0];
       xb("% 3d % 5d %6d %9d ", 1, score, (int)(get_timer()-start_time)/10000, (int)clock.nodes_searched);
-      print_principle_variation_xb(&movelist);
+      print_principle_variation_xb();
       xb("\n");
    }
    move_t move = best_move[0];
@@ -1334,7 +1350,7 @@ play_state_t think(int max_depth)
       for (int pv=0; pv<multipv; pv++) {
          if (pv > movelist.num_moves || exclude.num_moves >= movelist.num_moves) break;
          for (int window = 10; window < 2*LEGALWIN; window *= 2) {
-            if (depth <= 2) window = LEGALWIN / (depth - 1);
+            if (depth <= 2) window = (LEGALWIN+1000) / (depth - 1);
             if (mate_search && !is_mate_score(score)) window = LEGALWIN;
             int alpha = std::max(score - window, -LEGALWIN);
             int beta  = std::min(score + window,  LEGALWIN);
@@ -1394,7 +1410,7 @@ play_state_t think(int max_depth)
          iter("\n");
 
          xb("% 3d % 5d %6d %9d ", depth, score, (int)(get_timer()-start_time)/10000, (int)clock.nodes_searched);
-         print_principle_variation_xb(&movelist);
+         print_principle_variation_xb();
          xb("\n");
 
          uci("info depth %d score cp %d nodes %d time %d hashfull %d pv",
