@@ -21,6 +21,7 @@
 #	include <stdint.h>
 #	include <stdarg.h>
 #	include <stdio.h>
+#	if _MSC_VER < 1900
 int snprintf(char *buf, size_t size, const char *fmt, ...)
 {
 	int res;
@@ -30,4 +31,5 @@ int snprintf(char *buf, size_t size, const char *fmt, ...)
 	va_end(ap);
 	return res;
 }
+#	endif
 #endif
